/*
restart_io.c
functions called to copy restart info between restart structure and
active structures

*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
Biome-BGCMuSo v7.0.
Copyright 2000, Peter E. Thornton
Numerical Terradynamic Simulation Group (NTSG)
School of Forestry, University of Montana
Missoula, MT 59812
*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>
#include <malloc.h>
#include "ini.h"
#include "bgc_struct.h"     /* structure definitions */
#include "bgc_func.h"       /* function prototypes */
#include "bgc_constants.h"

int restart_input(const control_struct* ctrl, const epconst_struct* epc, const siteconst_struct* sitec,
	wstate_struct* ws, cstate_struct* cs, nstate_struct* ns, epvar_struct* epv, soilprop_struct* sprop, soilInfo_struct* soilInfo, restart_data_struct* restart)
{
	int errorCode=0;
	int layer;
	double soilw_sat,soilw_hw;
	
	
	/* 1. water: special case to initalize soil water from INI file - WSATE section (read_restart = 2) */
	if (ctrl->read_restart == 1)
	{
		for (layer =0; layer < N_SOILLAYERS; layer++)
		{ 
			ws->soilw[layer]                  = restart->soilw[layer];
			soilw_sat = sprop->VWCsat[layer] * sitec->soillayer_thickness[layer] * water_density;
			soilw_hw = sprop->VWChw[layer] * sitec->soillayer_thickness[layer] * water_density;
			if (soilw_sat < ws->soilw[layer]) ws->soilw[layer] = soilw_sat;
			if (soilw_hw > ws->soilw[layer]) ws->soilw[layer] = soilw_hw;
		}
		ws->snoww                             = restart->snoww;
	}

	ws->canopyw                           = restart->canopyw;

	/* 2. carbon and nitrogen plant pools */
	cs->leafc                             = restart->leafc;
	cs->leafc_storage                     = restart->leafc_storage;
	cs->leafc_transfer                    = restart->leafc_transfer;
	cs->frootc                            = restart->frootc;
	cs->frootc_storage                    = restart->frootc_storage;
	cs->frootc_transfer                   = restart->frootc_transfer;
	cs->yieldc                            = restart->yield;
	cs->yieldc_storage                    = restart->yieldc_storage;
	cs->yieldc_transfer                   = restart->yieldc_transfer;
	cs->softstemc                         = restart->softstemc;
	cs->softstemc_storage                 = restart->softstemc_storage;
	cs->softstemc_transfer                = restart->softstemc_transfer;

	cs->livestemc                         = restart->livestemc;
	cs->livestemc_storage                 = restart->livestemc_storage;
	cs->livestemc_transfer                = restart->livestemc_transfer;
	cs->deadstemc                         = restart->deadstemc;
	cs->deadstemc_storage                 = restart->deadstemc_storage;
	cs->deadstemc_transfer                = restart->deadstemc_transfer;
	cs->livecrootc                        = restart->livecrootc;
	cs->livecrootc_storage                = restart->livecrootc_storage;
	cs->livecrootc_transfer               = restart->livecrootc_transfer;
	cs->deadcrootc                        = restart->deadcrootc;
	cs->deadcrootc_storage                = restart->deadcrootc_storage;
	cs->deadcrootc_transfer               = restart->deadcrootc_transfer;
	cs->gresp_storage                     = restart->gresp_storage;
	cs->gresp_transfer                    = restart->gresp_transfer;

	cs->cpool                             = restart->cpool;
	
	ns->npool                             = restart->npool;

	ns->retransn			              = restart->retransn;

	/* spinup - normal C and N pool adjustment in order to avoud negative N pools in case of land use change (changing EOC) */
	if (epc->leaf_cn > 0)
	{
		ns->leafn                         = cs->leafc           / epc->leaf_cn;
		ns->leafn_storage                 = cs->leafc_storage   / epc->leaf_cn;
		ns->leafn_transfer                = cs->leafc_transfer  / epc->leaf_cn;
	}
	else
	{
		ns->leafn                         = 0;
		ns->leafn_storage                 = 0;
		ns->leafn_transfer                = 0;
	}

	if (epc->froot_cn)
	{
		ns->frootn                        = cs->frootc          / epc->froot_cn;
		ns->frootn_storage                = cs->frootc_storage  / epc->froot_cn;
		ns->frootn_transfer               = cs->frootc_transfer / epc->froot_cn;
	}
	else
	{
		ns->frootn                        = 0;
		ns->frootn_storage                = 0;
		ns->frootn_transfer               = 0;
	}

	if (epc->yield_cn > 0)
	{
		ns->yieldn                        = cs->yieldc          / epc->yield_cn;
		ns->yieldn_storage                = cs->yieldc_storage  / epc->yield_cn;
		ns->yieldn_transfer               = cs->yieldc_transfer / epc->yield_cn;
	}
	else
	{
		ns->yieldn                        =	0;
		ns->yieldn_storage                = 0;
		ns->yieldn_transfer               = 0;
	}
	
	if (epc->softstem_cn)
	{
		ns->softstemn                     = cs->softstemc          / epc->softstem_cn;
		ns->softstemn_storage             = cs->softstemc_storage  / epc->softstem_cn;
		ns->softstemn_transfer            = cs->softstemc_transfer / epc->softstem_cn;
	}
	else
	{
		ns->softstemn                     = 0;
		ns->softstemn_storage             = 0;
		ns->softstemn_transfer            = 0;
	}

	if (epc->livewood_cn > 0)
	{
		ns->livestemn                     = cs->livestemc          / epc->livewood_cn;
		ns->livestemn_storage             = cs->livestemc_storage  / epc->livewood_cn;
		ns->livestemn_transfer            = cs->livestemc_transfer / epc->livewood_cn;
		ns->livecrootn                    = cs->livecrootc         / epc->livewood_cn;
		ns->livecrootn_storage            = cs->livecrootc_storage / epc->livewood_cn;
		ns->livecrootn_transfer           = cs->livecrootc_transfer/ epc->livewood_cn;
	}
	else
	{
		ns->livestemn                     = 0;
		ns->livestemn_storage             = 0;
		ns->livestemn_transfer            = 0;
		ns->livecrootn                    = 0;
		ns->livecrootn_storage            = 0;
		ns->livecrootn_transfer           = 0;
	}
	
	if (epc->deadwood_cn > 0)
	{
		ns->deadstemn                     = cs->deadstemc          / epc->deadwood_cn; 
		ns->deadstemn_storage             = cs->deadstemc_storage  / epc->deadwood_cn;
		ns->deadstemn_transfer            = cs->deadstemc_transfer / epc->deadwood_cn;
		ns->deadcrootn                    = cs->deadcrootc         / epc->deadwood_cn;
		ns->deadcrootn_storage            = cs->deadcrootc_storage / epc->deadwood_cn;
		ns->deadcrootn_transfer           = cs->deadcrootc_transfer/ epc->deadwood_cn;
	
	}
	else
	{
		ns->deadstemn                     = 0; 
		ns->deadstemn_storage             = 0;
		ns->deadstemn_transfer            = 0;
		ns->deadcrootn                    = 0;
		ns->deadcrootn_storage            = 0;
		ns->deadcrootn_transfer           = 0;
	
	}

	/* 3. standing dead biomass, cut-down dead biomass and litter pools */
	cs->STDBc_leaf		= restart->STDBc_leaf;
	cs->STDBc_froot		= restart->STDBc_froot;
	cs->STDBc_yield		= restart->STDBc_yield;
	cs->STDBc_softstem	= restart->STDBc_softstem;
	cs->CTDBc_leaf		= restart->CTDBc_leaf;
	cs->CTDBc_froot		= restart->CTDBc_froot;
	cs->CTDBc_yield		= restart->CTDBc_yield;
	cs->CTDBc_softstem	= restart->CTDBc_softstem;
	cs->CTDBc_cstem		= restart->CTDBc_cstem;
	cs->CTDBc_croot		= restart->CTDBc_croot;
	
	ns->STDBn_leaf		= restart->STDBn_leaf;
	ns->STDBn_froot		= restart->STDBn_froot;
	ns->STDBn_yield		= restart->STDBn_yield;
	ns->STDBn_softstem	= restart->STDBn_softstem;
	ns->CTDBn_leaf		= restart->CTDBn_leaf;
	ns->CTDBn_froot		= restart->CTDBn_froot;
	ns->CTDBn_yield		= restart->CTDBn_yield;
	ns->CTDBn_softstem	= restart->CTDBn_softstem;
	ns->CTDBn_cstem		= restart->CTDBn_cstem;
	ns->CTDBn_croot		= restart->CTDBn_croot;

	/* 4. litter*/

	cs->litrc_above     = restart->litrc_above;
	cs->cwdc_above      = restart->cwdc_above;

	for (layer=0; layer < N_SOILLAYERS; layer++)
	{
		
 		cs->litr1c[layer]                 = restart->litr1c[layer];
		cs->litr2c[layer]                 = restart->litr2c[layer];
		cs->litr3c[layer]                 = restart->litr3c[layer];
		cs->litr4c[layer]                 = restart->litr4c[layer];
		cs->soil1c[layer]                 = restart->soil1c[layer];
		cs->soil2c[layer]                 = restart->soil2c[layer];
		cs->soil3c[layer]                 = restart->soil3c[layer];
		cs->soil4c[layer]                 = restart->soil4c[layer];
		cs->cwdc[layer]                   = restart->cwdc[layer];

 		ns->litr1n[layer]                 = restart->litr1n[layer];
		ns->litr2n[layer]                 = restart->litr2n[layer];
		ns->litr3n[layer]                 = restart->litr3n[layer];
		ns->litr4n[layer]                 = restart->litr4n[layer];
		ns->soil1n[layer]                 = restart->soil1n[layer];
		ns->soil2n[layer]                 = restart->soil2n[layer];
		ns->soil3n[layer]                 = restart->soil3n[layer];
		ns->soil4n[layer]                 = restart->soil4n[layer];
		ns->cwdn[layer]                   = restart->cwdn[layer];
		
		ns->NH4[layer]      = restart->NH4[layer];
		ns->NO3[layer]      = restart->NO3[layer];
	}

	/* 4. ecophysiological variables */
	epv->annmax_leafc                     = restart->annmax_leafc;
	epv->annmax_frootc                    = restart->annmax_frootc;
	epv->annmax_yieldc                    = restart->annmax_yieldc;
	epv->annmax_softstemc                 = restart->annmax_softstemc;
	epv->annmax_livestemc                 = restart->annmax_livestemc;
	epv->annmax_livecrootc                = restart->annmax_livecrootc;

	soilInfo->content_NORMcf[0] = restart->NH4content_NORMcf;
	soilInfo->content_NORMcf[1] = restart->NO3content_NORMcf;
	soilInfo->content_NORMcf[2] = restart->SOIL1N_content_NORMcf;
	soilInfo->content_NORMcf[3] = restart->SOIL2N_content_NORMcf;
	soilInfo->content_NORMcf[4] = restart->SOIL3N_content_NORMcf;
	soilInfo->content_NORMcf[5] = restart->SOIL4N_content_NORMcf;
	soilInfo->content_NORMcf[6] = restart->SOIL1C_content_NORMcf;
	soilInfo->content_NORMcf[7] = restart->SOIL2C_content_NORMcf;
	soilInfo->content_NORMcf[8] = restart->SOIL3C_content_NORMcf;
	soilInfo->content_NORMcf[9] = restart->SOIL4C_content_NORMcf;
	soilInfo->content_CAPILcf[0] = restart->NH4content_CAPILcf;
	soilInfo->content_CAPILcf[1] = restart->NO3content_CAPILcf;
	soilInfo->content_CAPILcf[2] = restart->SOIL1N_content_CAPILcf;
	soilInfo->content_CAPILcf[3] = restart->SOIL2N_content_CAPILcf;
	soilInfo->content_CAPILcf[4] = restart->SOIL3N_content_CAPILcf;
	soilInfo->content_CAPILcf[5] = restart->SOIL4N_content_CAPILcf;
	soilInfo->content_CAPILcf[6] = restart->SOIL1C_content_CAPILcf;
	soilInfo->content_CAPILcf[7] = restart->SOIL2C_content_CAPILcf;
	soilInfo->content_CAPILcf[8] = restart->SOIL3C_content_CAPILcf;
	soilInfo->content_CAPILcf[9] = restart->SOIL4C_content_CAPILcf;
	soilInfo->content_NORMgw[0] = restart->NH4content_NORMgw;
	soilInfo->content_NORMgw[1] = restart->NO3content_NORMgw;
	soilInfo->content_NORMgw[2] = restart->SOIL1N_content_NORMgw;
	soilInfo->content_NORMgw[3] = restart->SOIL2N_content_NORMgw;
	soilInfo->content_NORMgw[4] = restart->SOIL3N_content_NORMgw;
	soilInfo->content_NORMgw[5] = restart->SOIL4N_content_NORMgw;
	soilInfo->content_NORMgw[6] = restart->SOIL1C_content_NORMgw;
	soilInfo->content_NORMgw[7] = restart->SOIL2C_content_NORMgw;
	soilInfo->content_NORMgw[8] = restart->SOIL3C_content_NORMgw;
	soilInfo->content_NORMgw[9] = restart->SOIL4C_content_NORMgw;
	soilInfo->content_CAPILgw[0] = restart->NH4content_CAPILgw;
	soilInfo->content_CAPILgw[1] = restart->NO3content_CAPILgw;
	soilInfo->content_CAPILgw[2] = restart->SOIL1N_content_CAPILgw;
	soilInfo->content_CAPILgw[3] = restart->SOIL2N_content_CAPILgw;
	soilInfo->content_CAPILgw[4] = restart->SOIL3N_content_CAPILgw;
	soilInfo->content_CAPILgw[5] = restart->SOIL4N_content_CAPILgw;
	soilInfo->content_CAPILgw[6] = restart->SOIL1C_content_CAPILgw;
	soilInfo->content_CAPILgw[7] = restart->SOIL2C_content_CAPILgw;
	soilInfo->content_CAPILgw[8] = restart->SOIL3C_content_CAPILgw;
	soilInfo->content_CAPILgw[9] = restart->SOIL4C_content_CAPILgw;
	soilInfo->content_SATgw[0] = restart->NH4content_SATgw;
	soilInfo->content_SATgw[1] = restart->NO3content_SATgw;
	soilInfo->content_SATgw[2] = restart->SOIL1N_content_SATgw;
	soilInfo->content_SATgw[3] = restart->SOIL2N_content_SATgw;
	soilInfo->content_SATgw[4] = restart->SOIL3N_content_SATgw;
	soilInfo->content_SATgw[5] = restart->SOIL4N_content_SATgw;
	soilInfo->content_SATgw[6] = restart->SOIL1C_content_SATgw;
	soilInfo->content_SATgw[7] = restart->SOIL2C_content_SATgw;
	soilInfo->content_SATgw[8] = restart->SOIL3C_content_SATgw;
	soilInfo->content_SATgw[9] = restart->SOIL4C_content_SATgw;
	sprop->GWD_pre = restart->GWD_pre;
	sprop->CFD = restart->CFD;
	sprop->GWlayer = restart->GWlayer;
  	sprop->CFlayer = restart->CFlayer;
	sprop->VWC_NORMcf = restart->VWC_NORMcf;
	sprop->VWC_CAPILcf = restart->VWC_CAPILcf;
	sprop->soilw_NORMcf = restart->soilw_NORMcf;
	sprop->soilw_CAPILcf = restart->soilw_CAPILcf;
	sprop->dz_NORMcf = restart->dz_NORMcf;
	sprop->dz_CAPILcf = restart->dz_CAPILcf;
	sprop->VWC_NORMgw = restart->VWC_NORMgw;
	sprop->VWC_CAPILgw = restart->VWC_CAPILgw;
	sprop->soilw_NORMgw = restart->soilw_NORMgw;
	sprop->soilw_CAPILgw = restart->soilw_CAPILgw;
	sprop->soilw_SATgw = restart->soilw_SATgw;
	sprop->dz_NORMgw = restart->dz_NORMgw;
	sprop->dz_CAPILgw = restart->dz_CAPILgw;
	sprop->dz_SATgw = restart->dz_SATgw;


	return(errorCode);
}

int restart_output(const wstate_struct* ws, const cstate_struct* cs, const nstate_struct* ns, const epvar_struct* epv, const soilInfo_struct* soilInfo, const soilprop_struct* sprop, restart_data_struct* restart)
{
	int errorCode=0;
	int layer;

	/* 1. soil water */
	for (layer =0; layer < N_SOILLAYERS; layer++)
	{ 
		restart->soilw[layer]  				  = ws->soilw[layer];
	}
	restart->snoww  						  = ws->snoww;
	restart->canopyw						  = ws->canopyw;

	/* 2. plant carbon and nitrogen pools */

	restart->leafc  						  = cs->leafc;
	restart->leafc_storage  				  = cs->leafc_storage;
	restart->leafc_transfer 				  = cs->leafc_transfer;
	restart->frootc 						  = cs->frootc;
	restart->frootc_storage 				  = cs->frootc_storage;
	restart->frootc_transfer				  = cs->frootc_transfer;
	restart->yield 						  = cs->yieldc;
	restart->yieldc_storage 				  = cs->yieldc_storage;
	restart->yieldc_transfer				  = cs->yieldc_transfer;
	restart->softstemc 						  = cs->softstemc;
	restart->softstemc_storage 				  = cs->softstemc_storage;
	restart->softstemc_transfer				  = cs->softstemc_transfer;
	restart->livestemc  					  = cs->livestemc;
	restart->livestemc_storage  			  = cs->livestemc_storage;
	restart->livestemc_transfer 			  = cs->livestemc_transfer;
	restart->deadstemc  					  = cs->deadstemc;
	restart->deadstemc_storage  			  = cs->deadstemc_storage;
	restart->deadstemc_transfer 			  = cs->deadstemc_transfer;
	restart->livecrootc 					  = cs->livecrootc;
	restart->livecrootc_storage 			  = cs->livecrootc_storage;
	restart->livecrootc_transfer			  = cs->livecrootc_transfer;
	restart->deadcrootc 					  = cs->deadcrootc;
	restart->deadcrootc_storage 			  = cs->deadcrootc_storage;
	restart->deadcrootc_transfer			  = cs->deadcrootc_transfer;
	restart->gresp_storage  				  = cs->gresp_storage;
	restart->gresp_transfer 				  = cs->gresp_transfer;
	restart->cpool  						  = cs->cpool;

	restart->leafn  						  = ns->leafn;
	restart->leafn_storage  				  = ns->leafn_storage;
	restart->leafn_transfer 				  = ns->leafn_transfer;
	restart->frootn 						  = ns->frootn;
	restart->frootn_storage 				  = ns->frootn_storage;
	restart->frootn_transfer				  = ns->frootn_transfer;
	restart->yieldn  						  = ns->yieldn;
	restart->yieldn_storage  				  = ns->yieldn_storage;
	restart->yieldn_transfer 				  = ns->yieldn_transfer;
	restart->softstemn  					  = ns->softstemn;
	restart->softstemn_storage  			  = ns->softstemn_storage;
	restart->softstemn_transfer 			  = ns->softstemn_transfer;
	restart->livestemn  					  = ns->livestemn;
	restart->livestemn_storage  			  = ns->livestemn_storage;
	restart->livestemn_transfer 			  = ns->livestemn_transfer;
	restart->deadstemn  					  = ns->deadstemn;
	restart->deadstemn_storage  			  = ns->deadstemn_storage;
	restart->deadstemn_transfer 			  = ns->deadstemn_transfer;
	restart->livecrootn 					  = ns->livecrootn;
	restart->livecrootn_storage 			  = ns->livecrootn_storage;
	restart->livecrootn_transfer			  = ns->livecrootn_transfer;
	restart->deadcrootn 					  = ns->deadcrootn;
	restart->deadcrootn_storage 			  = ns->deadcrootn_storage;
	restart->deadcrootn_transfer			  = ns->deadcrootn_transfer;

	restart->retransn           			  = ns->retransn;
	restart->npool  						  = ns->npool;

	/* 2. standing dead biomass, cut-down dead biomass*/
	restart->STDBc_leaf			= cs->STDBc_leaf;
	restart->STDBc_froot		= cs->STDBc_froot;
	restart->STDBc_yield		= cs->STDBc_yield;
	restart->STDBc_softstem		= cs->STDBc_softstem;
	restart->CTDBc_leaf			= cs->CTDBc_leaf;
	restart->CTDBc_froot		= cs->CTDBc_froot;
	restart->CTDBc_yield		= cs->CTDBc_yield;
	restart->CTDBc_softstem		= cs->CTDBc_softstem;
	restart->CTDBc_cstem		= cs->CTDBc_cstem;
	restart->CTDBc_croot		= cs->CTDBc_croot;

	restart->STDBn_leaf			= ns->STDBn_leaf;
	restart->STDBn_froot		= ns->STDBn_froot;
	restart->STDBn_yield		= ns->STDBn_yield;
	restart->STDBn_softstem		= ns->STDBn_softstem;
	restart->CTDBn_leaf			= ns->CTDBn_leaf;
	restart->CTDBn_froot		= ns->CTDBn_froot;
	restart->CTDBn_yield		= ns->CTDBn_yield;
	restart->CTDBn_softstem		= ns->CTDBn_softstem;
	restart->CTDBn_cstem		= ns->CTDBn_cstem;
	restart->CTDBn_croot		= ns->CTDBn_croot;

	/* 3. multilayer litter and soil */

	
	restart->litrc_above     = cs->litrc_above;
	restart->cwdc_above      = cs->cwdc_above;

	for (layer=0; layer < N_SOILLAYERS; layer++)
	{
		restart->soil1c[layer] 	= cs->soil1c[layer];
		restart->soil2c[layer]  = cs->soil2c[layer];
		restart->soil3c[layer]  = cs->soil3c[layer];
		restart->soil4c[layer]  = cs->soil4c[layer];
		restart->litr1c[layer]  = cs->litr1c[layer];
		restart->litr2c[layer]  = cs->litr2c[layer];
		restart->litr3c[layer]  = cs->litr3c[layer];
		restart->litr4c[layer]  = cs->litr4c[layer];
		restart->cwdc[layer]	= cs->cwdc[layer];

		restart->soil1n[layer] 	= ns->soil1n[layer];
		restart->soil2n[layer]  = ns->soil2n[layer];
		restart->soil3n[layer]  = ns->soil3n[layer];
		restart->soil4n[layer]  = ns->soil4n[layer];
		restart->litr1n[layer]  = ns->litr1n[layer];
		restart->litr2n[layer]  = ns->litr2n[layer];
		restart->litr3n[layer]  = ns->litr3n[layer];
		restart->litr4n[layer]  = ns->litr4n[layer];
		restart->cwdn[layer]	= ns->cwdn[layer];

		restart->NH4[layer]  = ns->NH4[layer];
		restart->NO3[layer]  = ns->NO3[layer];
	}
	
	/* 4. ecophysiological variables */
	
	
	restart->annmax_leafc					  = epv->annmax_leafc;
	restart->annmax_frootc  				  = epv->annmax_frootc;
	restart->annmax_yieldc  				  = epv->annmax_yieldc;
	restart->annmax_softstemc  				  = epv->annmax_softstemc;
	restart->annmax_livestemc				  = epv->annmax_livestemc;
	restart->annmax_livecrootc  			  = epv->annmax_livecrootc;

	restart->NH4content_NORMcf = soilInfo->content_NORMcf[0];
	restart->NO3content_NORMcf = soilInfo->content_NORMcf[1];
	restart->SOIL1N_content_NORMcf = soilInfo->content_NORMcf[2];
	restart->SOIL2N_content_NORMcf = soilInfo->content_NORMcf[3];
	restart->SOIL3N_content_NORMcf = soilInfo->content_NORMcf[4];
	restart->SOIL4N_content_NORMcf = soilInfo->content_NORMcf[5];
	restart->SOIL1C_content_NORMcf = soilInfo->content_NORMcf[6];
	restart->SOIL2C_content_NORMcf = soilInfo->content_NORMcf[7];
	restart->SOIL3C_content_NORMcf = soilInfo->content_NORMcf[8];
	restart->SOIL4C_content_NORMcf = soilInfo->content_NORMcf[9];
	restart->NH4content_CAPILcf = soilInfo->content_CAPILcf[0];
	restart->NO3content_CAPILcf = soilInfo->content_CAPILcf[1];
	restart->SOIL1N_content_CAPILcf = soilInfo->content_CAPILcf[2];
	restart->SOIL2N_content_CAPILcf = soilInfo->content_CAPILcf[3];
	restart->SOIL3N_content_CAPILcf = soilInfo->content_CAPILcf[4];
	restart->SOIL4N_content_CAPILcf = soilInfo->content_CAPILcf[5];
	restart->SOIL1C_content_CAPILcf = soilInfo->content_CAPILcf[6];
	restart->SOIL2C_content_CAPILcf = soilInfo->content_CAPILcf[7];
	restart->SOIL3C_content_CAPILcf = soilInfo->content_CAPILcf[8];
	restart->SOIL4C_content_CAPILcf = soilInfo->content_CAPILcf[9];
	restart->NH4content_NORMgw = soilInfo->content_NORMgw[0];
	restart->NO3content_NORMgw = soilInfo->content_NORMgw[1];
	restart->SOIL1N_content_NORMgw = soilInfo->content_NORMgw[2];
	restart->SOIL2N_content_NORMgw = soilInfo->content_NORMgw[3];
	restart->SOIL3N_content_NORMgw = soilInfo->content_NORMgw[4];
	restart->SOIL4N_content_NORMgw = soilInfo->content_NORMgw[5];
	restart->SOIL1C_content_NORMgw = soilInfo->content_NORMgw[6];
	restart->SOIL2C_content_NORMgw = soilInfo->content_NORMgw[7];
	restart->SOIL3C_content_NORMgw = soilInfo->content_NORMgw[8];
	restart->SOIL4C_content_NORMgw = soilInfo->content_NORMgw[9];
	restart->NH4content_CAPILgw = soilInfo->content_CAPILgw[0];
	restart->NO3content_CAPILgw = soilInfo->content_CAPILgw[1];
	restart->SOIL1N_content_CAPILgw = soilInfo->content_CAPILgw[2];
	restart->SOIL2N_content_CAPILgw = soilInfo->content_CAPILgw[3];
	restart->SOIL3N_content_CAPILgw = soilInfo->content_CAPILgw[4];
	restart->SOIL4N_content_CAPILgw = soilInfo->content_CAPILgw[5];
	restart->SOIL1C_content_CAPILgw = soilInfo->content_CAPILgw[6];
	restart->SOIL2C_content_CAPILgw = soilInfo->content_CAPILgw[7];
	restart->SOIL3C_content_CAPILgw = soilInfo->content_CAPILgw[8];
	restart->SOIL4C_content_CAPILgw = soilInfo->content_CAPILgw[9];
	restart->NH4content_SATgw = soilInfo->content_SATgw[0];
	restart->NO3content_SATgw = soilInfo->content_SATgw[1];
	restart->SOIL1N_content_SATgw = soilInfo->content_SATgw[2];
	restart->SOIL2N_content_SATgw = soilInfo->content_SATgw[3];
	restart->SOIL3N_content_SATgw = soilInfo->content_SATgw[4];
	restart->SOIL4N_content_SATgw = soilInfo->content_SATgw[5];
	restart->SOIL1C_content_SATgw = soilInfo->content_SATgw[6];
	restart->SOIL2C_content_SATgw = soilInfo->content_SATgw[7];
	restart->SOIL3C_content_SATgw = soilInfo->content_SATgw[8];
	restart->SOIL4C_content_SATgw = soilInfo->content_SATgw[9];
	restart->GWD_pre = sprop->GWD;
	restart->GWlayer_pre = sprop->GWlayer;
	restart->CFD = sprop->CFD;
	restart->GWlayer = sprop->GWlayer;
	restart->CFlayer = sprop->CFlayer;
	restart->VWC_NORMgw = sprop->VWC_NORMgw;
	restart->VWC_CAPILgw = sprop->VWC_CAPILgw;
	restart->soilw_NORMgw = sprop->soilw_NORMgw;
	restart->soilw_CAPILgw = sprop->soilw_CAPILgw;
	restart->soilw_SATgw = sprop->soilw_SATgw;
	restart->dz_NORMgw = sprop->dz_NORMgw;
	restart->dz_CAPILgw = sprop->dz_CAPILgw;
	restart->dz_SATgw = sprop->dz_SATgw;
	restart->VWC_NORMcf = sprop->VWC_NORMcf;
	restart->VWC_CAPILcf = sprop->VWC_CAPILcf;
	restart->soilw_NORMcf = sprop->soilw_NORMcf;
	restart->soilw_CAPILcf = sprop->soilw_CAPILcf;
	restart->dz_NORMcf = sprop->dz_NORMcf;
	restart->dz_CAPILcf = sprop->dz_CAPILcf;



	return(errorCode);
}
